@@ -1,18 +1,16 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use crate::ast_parser::get_default_ts_config;
-use crate::ast_parser::AstParser;
-use crate::ast_parser::SwcDiagnostic;
+use crate::ast_parser::parse_program;
 use crate::context::Context;
 use crate::control_flow::ControlFlow;
 use crate::diagnostic::LintDiagnostic;
 use crate::ignore_directives::{
   parse_file_ignore_directives, parse_line_ignore_directives,
 };
-use crate::rules::LintRule;
+use crate::rules::{ban_unknown_rule_code::BanUnknownRuleCode, LintRule};
 use crate::scopes::Scope;
-use deno_ast::swc::common::SyntaxContext;
-use deno_ast::swc::parser::Syntax;
 use deno_ast::view::ProgramRef;
+use deno_ast::Diagnostic;
+use deno_ast::MediaType;
 use deno_ast::ParsedSource;
 use std::sync::Arc;
 use std::time::Instant;
@@ -23,9 +21,9 @@ pub use deno_ast::view::SourceFile;
 pub struct LinterBuilder {
   ignore_file_directive: String,
   ignore_diagnostic_directive: String,
-  syntax: deno_ast::swc::parser::Syntax,
-  rules: Arc<Vec<Box<dyn LintRule>>>,
-  plugins: Arc<Vec<Box<dyn Plugin>>>,
+  media_type: MediaType,
+  rules: Vec<Arc<dyn LintRule>>,
+  plugins: Vec<Arc<dyn Plugin>>,
 }
 
 impl LinterBuilder {
@@ -33,7 +31,7 @@ impl LinterBuilder {
     Self {
       ignore_file_directive: "deno-lint-ignore-file".to_string(),
       ignore_diagnostic_directive: "deno-lint-ignore".to_string(),
-      syntax: get_default_ts_config(),
+      media_type: MediaType::TypeScript,
       ..Default::default()
     }
   }
@@ -42,60 +40,73 @@ impl LinterBuilder {
     Linter::new(
       self.ignore_file_directive,
       self.ignore_diagnostic_directive,
-      self.syntax,
+      self.media_type,
       self.rules,
       self.plugins,
     )
   }
 
+  /// Set name for directive that can be used to skip linting file.
+  ///
+  /// Defaults to "deno-lint-ignore-file".
   pub fn ignore_file_directive(mut self, directive: &str) -> Self {
     self.ignore_file_directive = directive.to_owned();
     self
   }
 
+  /// Set name for directive that can be used to ignore next line.
+  ///
+  /// Defaults to "deno-lint-ignore".
   pub fn ignore_diagnostic_directive(mut self, directive: &str) -> Self {
     self.ignore_diagnostic_directive = directive.to_owned();
     self
   }
 
-  pub fn syntax(mut self, syntax: Syntax) -> Self {
-    self.syntax = syntax;
+  /// Set media type of a file to be linted.
+  ///
+  /// Defaults to `MediaType::TypeScript`
+  pub fn media_type(mut self, media_type: MediaType) -> Self {
+    self.media_type = media_type;
     self
   }
 
-  pub fn rules(mut self, rules: Arc<Vec<Box<dyn LintRule>>>) -> Self {
+  /// Set a list of rules that will be used for linting.
+  ///
+  /// Defaults to empty list (no rules will be run by default).
+  pub fn rules(mut self, rules: Vec<Arc<dyn LintRule>>) -> Self {
     self.rules = rules;
     self
   }
 
-  pub fn plugins(mut self, plugins: Arc<Vec<Box<dyn Plugin>>>) -> Self {
+  /// Set a list of plugins that will executed.
+  ///
+  /// Defaults to empty list (no plugins will be loaded).
+  pub fn plugins(mut self, plugins: Vec<Arc<dyn Plugin>>) -> Self {
     self.plugins = plugins;
     self
   }
 }
 
 pub struct Linter {
-  ast_parser: AstParser,
   ignore_file_directive: String,
   ignore_diagnostic_directive: String,
-  syntax: Syntax,
-  rules: Arc<Vec<Box<dyn LintRule>>>,
-  plugins: Arc<Vec<Box<dyn Plugin>>>,
+  media_type: MediaType,
+  rules: Vec<Arc<dyn LintRule>>,
+  plugins: Vec<Arc<dyn Plugin>>,
 }
 
 impl Linter {
   fn new(
     ignore_file_directive: String,
     ignore_diagnostic_directive: String,
-    syntax: Syntax,
-    rules: Arc<Vec<Box<dyn LintRule>>>,
-    plugins: Arc<Vec<Box<dyn Plugin>>>,
+    media_type: MediaType,
+    rules: Vec<Arc<dyn LintRule>>,
+    plugins: Vec<Arc<dyn Plugin>>,
   ) -> Self {
     Linter {
-      ast_parser: AstParser::new(),
       ignore_file_directive,
       ignore_diagnostic_directive,
-      syntax,
+      media_type,
       rules,
       plugins,
     }
@@ -105,18 +116,18 @@ impl Linter {
     mut self,
     file_name: String,
     source_code: String,
-  ) -> Result<(ParsedSource, Vec<LintDiagnostic>), SwcDiagnostic> {
+  ) -> Result<(ParsedSource, Vec<LintDiagnostic>), Diagnostic> {
     let start = Instant::now();
 
-    let parse_result =
-      self
-        .ast_parser
-        .parse_program(&file_name, self.syntax, source_code);
+    let syntax = deno_ast::get_syntax(self.media_type);
+    let parse_result = parse_program(&file_name, syntax, source_code);
+
     let end_parse_program = Instant::now();
     debug!(
       "ast_parser.parse_program took {:#?}",
       end_parse_program - start
     );
+
     let parsed_source = parse_result?;
     let diagnostics = self.lint_program(&parsed_source);
 
@@ -141,10 +152,10 @@ impl Linter {
     let start = Instant::now();
 
     let mut filtered_diagnostics = context.check_ignore_directive_usage();
-    // Run `ban-unused-ignore`
-    filtered_diagnostics.extend(context.ban_unused_ignore(&self.rules));
     // Run `ban-unknown-rule-code`
     filtered_diagnostics.extend(context.ban_unknown_rule_code());
+    // Run `ban-unused-ignore`
+    filtered_diagnostics.extend(context.ban_unused_ignore(&self.rules));
     filtered_diagnostics.sort_by_key(|d| d.range.start.line_index);
 
     let end = Instant::now();
@@ -158,13 +169,11 @@ impl Linter {
     parsed_source: &ParsedSource,
   ) -> Vec<LintDiagnostic> {
     let start = Instant::now();
-
+    let check_unknown_rules = self
+      .rules
+      .iter()
+      .any(|a| a.code() == (BanUnknownRuleCode).code());
     let control_flow = ControlFlow::analyze(parsed_source.program_ref().into());
-    let top_level_ctxt = deno_ast::swc::common::GLOBALS
-      .set(&self.ast_parser.globals, || {
-        SyntaxContext::empty().apply_mark(self.ast_parser.top_level_mark)
-      });
-
     let diagnostics = parsed_source.with_view(|pg| {
       let file_ignore_directive =
         parse_file_ignore_directives(&self.ignore_file_directive, pg);
@@ -183,20 +192,25 @@ impl Linter {
 
       let mut context = Context::new(
         parsed_source.specifier().to_string(),
+        self.media_type,
         parsed_source.source(),
         pg,
         file_ignore_directive,
         line_ignore_directives,
         scope,
         control_flow,
-        top_level_ctxt,
+        parsed_source.top_level_context(),
+        check_unknown_rules,
       );
 
+      crate::rules::sort_rules_by_priority(&mut self.rules);
+
       // Run builtin rules
       for rule in self.rules.iter() {
         rule.lint_program_with_ast_view(&mut context, pg);
       }
 
+      // TODO(bartlomieju): plugins rules should be sorted by priority as well.
       // Run plugin rules
       for plugin in self.plugins.iter() {
         // Ignore any error
