@@ -1,15 +1,18 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
 use super::{Context, LintRule};
 use crate::{Program, ProgramRef};
+use std::sync::Arc;
 
 /// This is a dummy struct just for having the docs.
 /// The actual implementation resides in [`Context`].
 #[derive(Debug)]
 pub struct BanUnknownRuleCode;
 
+pub(crate) const CODE: &str = "ban-unknown-rule-code";
+
 impl LintRule for BanUnknownRuleCode {
-  fn new() -> Box<Self> {
-    Box::new(BanUnknownRuleCode)
+  fn new() -> Arc<Self> {
+    Arc::new(BanUnknownRuleCode)
   }
 
   fn tags(&self) -> &'static [&'static str] {
@@ -17,7 +20,7 @@ impl LintRule for BanUnknownRuleCode {
   }
 
   fn code(&self) -> &'static str {
-    "ban-unknown-rule-code"
+    CODE
   }
 
   fn lint_program(&self, _context: &mut Context, _program: ProgramRef<'_>) {
@@ -36,4 +39,9 @@ impl LintRule for BanUnknownRuleCode {
   fn docs(&self) -> &'static str {
     include_str!("../../docs/rules/ban_unknown_rule_code.md")
   }
+
+  // This rule should be run second to last.
+  fn priority(&self) -> u32 {
+    u32::MAX - 1
+  }
 }
